use maud::{html, PreEscaped};
use rouille::Request;

use crate::{
    templates,
    utils::{flash::FlashRequest, theme},
};

// ROUTE: /auth/forgot

/// Forgot password template builder.
pub fn build_template(request: &Request) -> PreEscaped<String> {
    // check for flash cookies; will be (None, None) if no flash cookies are found
    let (flash_name, flash_msg) = request.retrieve_flash();

    let password_reset_template = html! {
        (PreEscaped("<!-- PASSWORD RESET REQUEST CARD -->"))
        div class="card center" {
            div class="capsule capsule-container border-info" {
                p class="card-text" {
                    "Click the 'Send Temporary Password' button to send a new temporary password which can be used to change your device password."
                }
                p class="card-text" style="margin-top: 1rem;" {
                    "The temporary password will be sent in an SSB private message to the admin of this device."
                }
                p class="card-text" style="margin-top: 1rem;" {
                    "Once you have the temporary password, click the 'Set New Password' button to reach the password reset page."
                }
            }
            form id="sendPasswordReset" action="/auth/temporary" method="post" {
                div id="buttonDiv" {
                    input class="button button-primary center" style="margin-top: 1rem;" type="submit" value="Send Temporary Password" title="Send temporary password to Scuttlebutt admin(s)";
                    a href="/auth/reset_password" class="button button-primary center" title="Set a new password using the temporary password" {
                        "Set New Password"
                    }
                }
            }
            // render flash message if cookies were found in the request
            @if let (Some(name), Some(msg)) = (flash_name, flash_msg) {
                (PreEscaped("<!-- FLASH MESSAGE -->"))
                (templates::flash::build_template(name, msg))
            }
        }
    };

    // wrap the nav bars around the settings menu template content
    // parameters are template, title and back url
    let body =
        templates::nav::build_template(password_reset_template, "Send Password Reset", Some("/"));

    // query the current theme so we can pass it into the base template builder
    let theme = theme::get_theme();

    // render the base template with the provided body
    templates::base::build_template(body, theme)
}
