use maud::{html, PreEscaped};

use crate::{templates, utils::theme};

/// Guide template builder.
pub fn build_template() -> PreEscaped<String> {
    // render the guide template html
    let guide_template = html! {
        (PreEscaped("<!-- GUIDE -->"))
        div class="card card-wide center" {
            div class="capsule capsule-container border-info" {
                (PreEscaped("<!-- GETTING STARTED -->"))
                details {
                    summary class="card-text link" { "Getting started" }
                    p class="card-text" style="margin-top: 1rem; margin-bottom: 1rem;" {
                        "The Scuttlebutt server (sbot) will be inactive when you first run PeachCloud. This is to allow configuration parameters to be set before it is activated for the first time. Navigate to the "
                        strong {
                            a href="/settings/scuttlebutt/configure" class="link font-gray" {
                                "Sbot Configuration"
                            }
                        }
                        " page to configure your system. The default configuration will be fine for most usecases."
                    }
                    p class="card-text" style="margin-top: 1rem; margin-bottom: 1rem;" {
                        "Once the configuration is set, navigate to the "
                        strong {
                            a href="/settings/scuttlebutt" class="link font-gray" {
                                "Scuttlebutt settings menu"
                            }
                        }
                        " to start the sbot. If the server starts successfully, you will see a green smiley face on the home page. If the face is orange and sleeping, that means the sbot is still inactive (ie. the process is not running). If the face is red and dead, that means the sbot failed to start - indicated an error. For now, the best way to gain insight into the problem is to check the systemd log. Open a terminal and enter: "
                        code { "systemctl status go-sbot.service" }
                        ". The log output may give some clues about the source of the error."
                    }
                }
                (PreEscaped("<!-- BUG REPORTS -->"))
                details {
                    summary class="card-text link" { "Submit a bug report" }
                    p class="card-text" style="margin-top: 1rem; margin-bottom: 1rem;" {
                        "Bug reports can be submitted by "
                        strong {
                            a href="https://git.coopcloud.tech/PeachCloud/peach-workspace/issues/new?template=BUG_TEMPLATE.md" class="link font-gray" {
                                "filing an issue"
                            }
                        }
                        " on the peach-workspace git repo. Before filing a report, first check to see if an issue already exists for the bug you've encountered. If not, you're invited to submit a new report; the template will guide you through several questions."
                    }
                }
                (PreEscaped("<!-- REQUEST SUPPORT -->"))
                details {
                    summary class="card-text link" { "Share feedback & request support" }
                    p class="card-text" style="margin-top: 1rem; margin-bottom: 1rem;" {
                        "You're invited to share your thoughts and experiences of PeachCloud in the #peachcloud channel on Scuttlebutt. The channel is also a good place to ask for help."
                    }
                    p class="card-text" style="margin-top: 1rem; margin-bottom: 1rem;" {
                        "Alternatively, we have a "
                        strong {
                            a href="https://matrix.to/#/#peachcloud:matrix.org" class="link font-gray" {
                                "Matrix channel"
                            }
                        }
                        " for discussion about PeachCloud and you can also reach out to @glyph "
                        strong {
                            a href="mailto:glyph@mycelial.technology" class="link font-gray" {
                                "via email"
                            }
                        }
                        "."
                    }
                }
                (PreEscaped("<!-- CONTRIBUTE -->"))
                details {
                    summary class="card-text link" { "Contribute to PeachCloud" }
                    p class="card-text" style="margin-top: 1rem; margin-bottom: 1rem;" {
                        "PeachCloud is free, open-source software and relies on donations and grants to fund develop. Donations can be made on our "
                        strong {
                            a href="https://opencollective.com/peachcloud" class="link font-gray" {
                                "Open Collective"
                            }
                        }
                        " page."
                    }
                    p class="card-text" style="margin-top: 1rem; margin-bottom: 1rem;" {
                        "Programmers, designers, artists and writers are also welcome to contribute to the project. Please visit the "
                        strong {
                            a href="https://git.coopcloud.tech/PeachCloud/peach-workspace" class="link font-gray" {
                                "main PeachCloud git repository"
                            }
                        }
                        " to find out more details or contact the team via Scuttlebutt, Matrix or email."
                    }
                }
            }
        }
    };

    // wrap the nav bars around the home template content
    // title is "" and back button link is `None` because this is the homepage
    let body = templates::nav::build_template(guide_template, "Guide", Some("/"));

    // query the current theme so we can pass it into the base template builder
    let theme = theme::get_theme();

    // render the base template with the provided body
    templates::base::build_template(body, theme)
}
